*******************************************************************************
******			Hoffman & Stawski RHD Electronic Appendix 				*******
*******************************************************************************


* PROC MIXED syntax commands used below:

DATA gives file used for analysis
COVTEST gives significance tests of covariance parameters
NOCLPRINT suppresses class variable list
NOITPRINT suppresses iteration history print
NAMELEN=50 prints 50 characters for fixed effects (to limit truncation)
METHOD=ML specifies maximum likelihood (default is restricted ML)
CLASS defines categorical variables 
	include nesting variables (ID)
	include variables on REPEATED statement (session)
	include variables for heterogeneity of variance (old)
MODEL defines equation, where [outcome] = [predictors]
	/ SOLUTION asks for parameter estimates
	  DDFM=BW specifies Between-Within denominator degrees of freedom
	  NOTEST suppresses omnibus test (because not relevant here)
RANDOM lists random effects 
	/ SUBJECT=ID defines nesting structure for level 2 persons
	  TYPE=UN specifies unstructured matrix (all variances & covariances)
REPEATED allows structuring of the residual variance
	/ SUBJECT=ID defines nesting structure for level 2 persons
	  TYPE=VC specifies identity matrix (equal variances & no covariances)
GROUP=older indicates separate variances for each level of older 
ESTIMATE statements provide implicit model effects and SE's ;
 

*** BASELINE EMPTY LONGITUDINAL MODEL;
TITLE1 "Eq. 1: Empty Model for Symptoms";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept / TYPE=UN SUBJECT=ID;
	REPEATED session / TYPE=VC SUBJECT=ID;
	* ODS statement saves the covariance parameters to a dataset
	  for use in the program below that calculates an ICC for this outcome; 
	ODS OUTPUT CovParms=work.Covsave; 
RUN;

* Eq. 2: ICC calculator;
PROC TRANSPOSE DATA=Covsave OUT=ICC; ID CovParm; VAR Estimate; RUN;
DATA ICC; SET ICC; ICC = UN_1_1_/(UN_1_1_+session); RUN;
TITLE1 "ICCs from Empty Model";
PROC PRINT DATA=ICC NOOBS LABEL; VAR ICC; RUN; TITLE1;


*** AGE MODELS;
TITLE1 "Age Differences in # of Symptoms";
TITLE2 "Both Variances Homogeneous";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = old / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept / TYPE=UN SUBJECT=ID;
	REPEATED session / TYPE=VC SUBJECT=ID;
	ESTIMATE "Intercept: Young" intercept 1 old 1 0;
	ESTIMATE "Intercept: Old" intercept 1 old 0 1;
	ESTIMATE "Intercept: Age Diff" old -1 1;
run;
TITLE2 "Heterogeneous Random Intercept";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = old / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept / TYPE=UN SUBJECT=ID GROUP=old;
	REPEATED session / TYPE=VC SUBJECT=ID;
	ESTIMATE "Intercept: Young" intercept 1 old 1 0;
	ESTIMATE "Intercept: Old" intercept 1 old 0 1;
	ESTIMATE "Intercept: Age Diff" old -1 1;
run;
TITLE2 "Eq. 3: Age Heterogeneous Random Intercept and Residual";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = old / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept / TYPE=UN SUBJECT=ID GROUP=old;
	REPEATED session / TYPE=VC SUBJECT=ID GROUP=old;
	ESTIMATE "Intercept: Young" intercept 1 old 1 0;
	ESTIMATE "Intercept: Old" intercept 1 old 0 1;
	ESTIMATE "Intercept: Age Diff" old -1 1;
run;


*** STRESS MODELS;
TITLE1 "Empty Model for Stress"; TITLE2;
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 METHOD=ML;
	CLASS ID session old;
	MODEL daystress = / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept / TYPE=UN SUBJECT=ID;
	REPEATED session / TYPE=VC SUBJECT=ID;
run;
TITLE1 "Eq. 4: GMC Stress Model";
TITLE2 "No Age Interactions";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = old daystress /SOLUTION DDFM=BW NOTEST;
	RANDOM intercept / TYPE=UN SUBJECT=ID GROUP=old;
	REPEATED session / TYPE=VC SUBJECT=ID GROUP=old;
run;
TITLE1 "Eq. 5: GMC Stress Model + PMstress";
TITLE2 "No Age Interactions";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = old daystress pmstress /SOLUTION DDFM=BW NOTEST;
	RANDOM intercept / TYPE=UN SUBJECT=ID GROUP=old;
	REPEATED session / TYPE=VC SUBJECT=ID GROUP=old;
	ESTIMATE "WP Stress" 		daystress 1;
	ESTIMATE "Context Stress" 	pmstress 1;
	ESTIMATE "BP Stress" 		daystress 1 pmstress 1;
run;
TITLE1 "GMC Stress Model + PMstress";
TITLE2 "Add Stress Interactions with Age";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = daystress|old pmstress|old / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept / TYPE=UN SUBJECT=ID GROUP=old;
	REPEATED session / TYPE=VC SUBJECT=ID GROUP=old;
	ESTIMATE "Intercept: Young" 		intercept 1 old 1 0;
	ESTIMATE "Intercept: Old" 			intercept 1 old 0 1;
	ESTIMATE "Intercept: Age Diff"  	old -1 1;
	ESTIMATE "WP Stress: Young" 		daystress 1 daystress*old 1 0;
	ESTIMATE "WP Stress: Old" 			daystress 1 daystress*old 0 1;
	ESTIMATE "WP Stress: Age Diff"  	daystress*old -1 1;
	ESTIMATE "Context Stress: Young"	pmstress 1 pmstress*old 1 0;
	ESTIMATE "Context Stress: Old" 		pmstress 1 pmstress*old 0 1;
	ESTIMATE "Context Stress: Age Diff" pmstress*old -1 1;
	ESTIMATE "BP Stress: Young" 		daystress 1 pmstress 1 daystress*old 1 0 pmstress*old 1 0;
	ESTIMATE "BP Stress: Old" 			daystress 1 pmstress 1 daystress*old 0 1 pmstress*old 0 1;
	ESTIMATE "BP Stress: Age Diff" 		daystress*old -1 1 pmstress*old -1 1;
run;
TITLE1 "Eq. 6: GMC Stress Model + PMstress";
TITLE2 "Add Random Slopes for Stress";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = daystress|old pmstress|old / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept daystress / TYPE=UN SUBJECT=ID GROUP=old G GCORR;
	REPEATED session / TYPE=VC SUBJECT=ID GROUP=old;
	ESTIMATE "Intercept: Young" 		intercept 1 old 1 0;
	ESTIMATE "Intercept: Old" 			intercept 1 old 0 1;
	ESTIMATE "Intercept: Age Diff"  	old -1 1;
	ESTIMATE "WP Stress: Young" 		daystress 1 daystress*old 1 0;
	ESTIMATE "WP Stress: Old" 			daystress 1 daystress*old 0 1;
	ESTIMATE "WP Stress: Age Diff"  	daystress*old -1 1;
	ESTIMATE "Context Stress: Young"	pmstress 1 pmstress*old 1 0;
	ESTIMATE "Context Stress: Old" 		pmstress 1 pmstress*old 0 1;
	ESTIMATE "Context Stress: Age Diff" pmstress*old -1 1;
	ESTIMATE "BP Stress: Young" 		daystress 1 pmstress 1 daystress*old 1 0 pmstress*old 1 0;
	ESTIMATE "BP Stress: Old" 			daystress 1 pmstress 1 daystress*old 0 1 pmstress*old 0 1;
	ESTIMATE "BP Stress: Age Diff" 		daystress*old -1 1 pmstress*old -1 1;
run;
TITLE1 "GMC Stress Model + PMstress";
TITLE2 "Add PMstress*DayStress Interactions -- not signif";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = daystress|old pmstress|old daystress|pmstress|old / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept daystress / TYPE=UN SUBJECT=ID GROUP=old GCORR;
	REPEATED session / TYPE=VC SUBJECT=ID GROUP=old;
	ESTIMATE "Intercept: Young" 		intercept 1 old 1 0;
	ESTIMATE "Intercept: Old" 			intercept 1 old 0 1;
	ESTIMATE "Intercept: Age Diff"  	old -1 1;
	ESTIMATE "WP Stress: Young" 		daystress 1 daystress*old 1 0;
	ESTIMATE "WP Stress: Old" 			daystress 1 daystress*old 0 1;
	ESTIMATE "WP Stress: Age Diff"  	daystress*old -1 1;
	ESTIMATE "Context Stress: Young"	pmstress 1 pmstress*old 1 0;
	ESTIMATE "Context Stress: Old" 		pmstress 1 pmstress*old 0 1;
	ESTIMATE "Context Stress: Age Diff" pmstress*old -1 1;
	ESTIMATE "BP Stress: Young" 		daystress 1 pmstress 1 daystress*old 1 0 pmstress*old 1 0;
	ESTIMATE "BP Stress: Old" 			daystress 1 pmstress 1 daystress*old 0 1 pmstress*old 0 1;
	ESTIMATE "BP Stress: Age Diff" 		daystress*old -1 1 pmstress*old -1 1;
run;


*** NEGATIVE MOOD MODELS;
TITLE1 "Empty Model for Mood"; TITLE2;
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 METHOD=ML;
	CLASS ID session old;
	MODEL daymood = / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept / TYPE=UN SUBJECT=ID;
	REPEATED session / TYPE=VC SUBJECT=ID;
run;
TITLE1 "Eq. 7: PMC Model for Negative Mood";
TITLE2 "No Interactions";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = daystress|old pmstress|old wpmood pmmood / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept daystress / TYPE=UN SUBJECT=ID GROUP=old GCORR;
	REPEATED session / TYPE=VC SUBJECT=ID GROUP=old;
	ESTIMATE "Intercept: Young" 		intercept 1 old 1 0;
	ESTIMATE "Intercept: Old" 			intercept 1 old 0 1;
	ESTIMATE "Intercept: Age Diff"  	old -1 1;
	ESTIMATE "WP Stress: Young" 		daystress 1 daystress*old 1 0;
	ESTIMATE "WP Stress: Old" 			daystress 1 daystress*old 0 1;
	ESTIMATE "WP Stress: Age Diff"  	daystress*old -1 1;
	ESTIMATE "Context Stress: Young"	pmstress 1 pmstress*old 1 0;
	ESTIMATE "Context Stress: Old" 		pmstress 1 pmstress*old 0 1;
	ESTIMATE "Context Stress: Age Diff" pmstress*old -1 1;
	ESTIMATE "BP Stress: Young" 		daystress 1 pmstress 1 daystress*old 1 0 pmstress*old 1 0;
	ESTIMATE "BP Stress: Old" 			daystress 1 pmstress 1 daystress*old 0 1 pmstress*old 0 1;
	ESTIMATE "BP Stress: Age Diff" 		daystress*old -1 1 pmstress*old -1 1;
	ESTIMATE "WP Mood" 					wpmood 1;
	ESTIMATE "Context Mood" 			wpmood -1 pmmood 1;
	ESTIMATE "BP Mood" 					pmmood 1;
run;
TITLE1 "PMC Model for Negative Mood";
TITLE2 "Add Negative Mood Interactions with Age";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = daystress|old pmstress|old wpmood|old pmmood|old / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept daystress / TYPE=UN SUBJECT=ID GROUP=old GCORR;
	REPEATED session / TYPE=VC SUBJECT=ID GROUP=old;
	ESTIMATE "Intercept: Young" 		intercept 1 old 1 0;
	ESTIMATE "Intercept: Old" 			intercept 1 old 0 1;
	ESTIMATE "Intercept: Age Diff"  	old -1 1;
	ESTIMATE "WP Stress: Young" 		daystress 1 daystress*old 1 0;
	ESTIMATE "WP Stress: Old" 			daystress 1 daystress*old 0 1;
	ESTIMATE "WP Stress: Age Diff"  	daystress*old -1 1;
	ESTIMATE "Context Stress: Young"	pmstress 1 pmstress*old 1 0;
	ESTIMATE "Context Stress: Old" 		pmstress 1 pmstress*old 0 1;
	ESTIMATE "Context Stress: Age Diff" pmstress*old -1 1;
	ESTIMATE "BP Stress: Young" 		daystress 1 pmstress 1 daystress*old 1 0 pmstress*old 1 0;
	ESTIMATE "BP Stress: Old" 			daystress 1 pmstress 1 daystress*old 0 1 pmstress*old 0 1;
	ESTIMATE "BP Stress: Age Diff" 		daystress*old -1 1 pmstress*old -1 1;
	ESTIMATE "WP Mood: Young" 			wpmood 1 wpmood*old 1 0;
	ESTIMATE "WP Mood: Old"				wpmood 1 wpmood*old 0 1;
	ESTIMATE "WP Mood: Age Diff" 		wpmood*old -1 1;
	ESTIMATE "Context Mood: Young" 		wpmood -1 wpmood*old -1 0 pmmood 1 pmmood*old 1 0;
	ESTIMATE "Context Mood: Old"   		wpmood -1 wpmood*old 0 -1 pmmood 1 pmmood*old 0 1;
	ESTIMATE "Context Mood: Age Diff" 	wpmood*old 1 -1 pmmood*old -1 1;
	ESTIMATE "BP Mood: Young" 			pmmood 1 pmmood*old 1 0;
	ESTIMATE "BP Mood: Old" 			pmmood 1 pmmood*old 0 1;
	ESTIMATE "BP Mood: Age Diff" 		pmmood*old -1 1;
run;
TITLE1 "Eq. 8: PMC Model for Negative Mood";
TITLE2 "Add Random Slopes for WP Mood";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = daystress|old pmstress|old wpmood|old pmmood|old / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept daystress wpmood / TYPE=UN SUBJECT=ID GROUP=old G GCORR;
	REPEATED session / TYPE=VC SUBJECT=ID GROUP=old;
	ESTIMATE "Intercept: Young" 		intercept 1 old 1 0;
	ESTIMATE "Intercept: Old" 			intercept 1 old 0 1;
	ESTIMATE "Intercept: Age Diff"  	old -1 1;
	ESTIMATE "WP Stress: Young" 		daystress 1 daystress*old 1 0;
	ESTIMATE "WP Stress: Old" 			daystress 1 daystress*old 0 1;
	ESTIMATE "WP Stress: Age Diff"  	daystress*old -1 1;
	ESTIMATE "Context Stress: Young"	pmstress 1 pmstress*old 1 0;
	ESTIMATE "Context Stress: Old" 		pmstress 1 pmstress*old 0 1;
	ESTIMATE "Context Stress: Age Diff" pmstress*old -1 1;
	ESTIMATE "BP Stress: Young" 		daystress 1 pmstress 1 daystress*old 1 0 pmstress*old 1 0;
	ESTIMATE "BP Stress: Old" 			daystress 1 pmstress 1 daystress*old 0 1 pmstress*old 0 1;
	ESTIMATE "BP Stress: Age Diff" 		daystress*old -1 1 pmstress*old -1 1;
	ESTIMATE "WP Mood: Young" 			wpmood 1 wpmood*old 1 0;
	ESTIMATE "WP Mood: Old"				wpmood 1 wpmood*old 0 1;
	ESTIMATE "WP Mood: Age Diff" 		wpmood*old -1 1;
	ESTIMATE "Context Mood: Young" 		wpmood -1 wpmood*old -1 0 pmmood 1 pmmood*old 1 0;
	ESTIMATE "Context Mood: Old"   		wpmood -1 wpmood*old 0 -1 pmmood 1 pmmood*old 0 1;
	ESTIMATE "Context Mood: Age Diff" 	wpmood*old 1 -1 pmmood*old -1 1;
	ESTIMATE "BP Mood: Young" 			pmmood 1 pmmood*old 1 0;
	ESTIMATE "BP Mood: Old" 			pmmood 1 pmmood*old 0 1;
	ESTIMATE "BP Mood: Age Diff" 		pmmood*old -1 1;
run;
TITLE1 "PMC Model for Negative Mood";
TITLE2 "Add PMsmood*WPmood Interactions -- not signif";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = daystress|old pmstress|old wpmood|old pmmood|old wpmood|pmmood|old / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept daystress wpmood / TYPE=UN SUBJECT=ID GROUP=old GCORR;
	REPEATED session / TYPE=VC SUBJECT=ID GROUP=old;
	ESTIMATE "Intercept: Young" 		intercept 1 old 1 0;
	ESTIMATE "Intercept: Old" 			intercept 1 old 0 1;
	ESTIMATE "Intercept: Age Diff"  	old -1 1;
	ESTIMATE "WP Stress: Young" 		daystress 1 daystress*old 1 0;
	ESTIMATE "WP Stress: Old" 			daystress 1 daystress*old 0 1;
	ESTIMATE "WP Stress: Age Diff"  	daystress*old -1 1;
	ESTIMATE "Context Stress: Young"	pmstress 1 pmstress*old 1 0;
	ESTIMATE "Context Stress: Old" 		pmstress 1 pmstress*old 0 1;
	ESTIMATE "Context Stress: Age Diff" pmstress*old -1 1;
	ESTIMATE "BP Stress: Young" 		daystress 1 pmstress 1 daystress*old 1 0 pmstress*old 1 0;
	ESTIMATE "BP Stress: Old" 			daystress 1 pmstress 1 daystress*old 0 1 pmstress*old 0 1;
	ESTIMATE "BP Stress: Age Diff" 		daystress*old -1 1 pmstress*old -1 1;
	ESTIMATE "WP Mood: Young" 			wpmood 1 wpmood*old 1 0;
	ESTIMATE "WP Mood: Old"				wpmood 1 wpmood*old 0 1;
	ESTIMATE "WP Mood: Age Diff" 		wpmood*old -1 1;
	ESTIMATE "Context Mood: Young" 		wpmood -1 wpmood*old -1 0 pmmood 1 pmmood*old 1 0;
	ESTIMATE "Context Mood: Old"   		wpmood -1 wpmood*old 0 -1 pmmood 1 pmmood*old 0 1;
	ESTIMATE "Context Mood: Age Diff" 	wpmood*old 1 -1 pmmood*old -1 1;
	ESTIMATE "BP Mood: Young" 			pmmood 1 pmmood*old 1 0;
	ESTIMATE "BP Mood: Old" 			pmmood 1 pmmood*old 0 1;
	ESTIMATE "BP Mood: Age Diff" 		pmmood*old -1 1;
run;


*** TIME MODELS;
TITLE1 "Eq. 9: Adding Fixed Linear Time Trend"; 
TITLE2 "Adding Interactions with Age";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = daystress|old pmstress|old wpmood|old pmmood|old time|old / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept daystress wpmood / TYPE=UN SUBJECT=ID GROUP=old G GCORR;
	REPEATED session / TYPE=VC SUBJECT=ID GROUP=old;
	ESTIMATE "Intercept: Young" 		intercept 1 old 1 0;
	ESTIMATE "Intercept: Old" 			intercept 1 old 0 1;
	ESTIMATE "Intercept: Age Diff"  	old -1 1;
	ESTIMATE "WP Stress: Young" 		daystress 1 daystress*old 1 0;
	ESTIMATE "WP Stress: Old" 			daystress 1 daystress*old 0 1;
	ESTIMATE "WP Stress: Age Diff"  	daystress*old -1 1;
	ESTIMATE "Context Stress: Young"	pmstress 1 pmstress*old 1 0;
	ESTIMATE "Context Stress: Old" 		pmstress 1 pmstress*old 0 1;
	ESTIMATE "Context Stress: Age Diff" pmstress*old -1 1;
	ESTIMATE "BP Stress: Young" 		daystress 1 pmstress 1 daystress*old 1 0 pmstress*old 1 0;
	ESTIMATE "BP Stress: Old" 			daystress 1 pmstress 1 daystress*old 0 1 pmstress*old 0 1;
	ESTIMATE "BP Stress: Age Diff" 		daystress*old -1 1 pmstress*old -1 1;
	ESTIMATE "WP Mood: Young" 			wpmood 1 wpmood*old 1 0;
	ESTIMATE "WP Mood: Old"				wpmood 1 wpmood*old 0 1;
	ESTIMATE "WP Mood: Age Diff" 		wpmood*old -1 1;
	ESTIMATE "Context Mood: Young" 		wpmood -1 wpmood*old -1 0 pmmood 1 pmmood*old 1 0;
	ESTIMATE "Context Mood: Old"   		wpmood -1 wpmood*old 0 -1 pmmood 1 pmmood*old 0 1;
	ESTIMATE "Context Mood: Age Diff" 	wpmood*old 1 -1 pmmood*old -1 1;
	ESTIMATE "BP Mood: Young" 			pmmood 1 pmmood*old 1 0;
	ESTIMATE "BP Mood: Old" 			pmmood 1 pmmood*old 0 1;
	ESTIMATE "BP Mood: Age Diff" 		pmmood*old -1 1;
	ESTIMATE "Linear Trend: Young" 		time 1 time*old 1 0;
	ESTIMATE "Linear Trend: Old" 		time 1 time*old 0 1;
	ESTIMATE "Linear Trend: Age Diff" 	time*old -1 1;
run;
TITLE2 "Adding Random Slopes for Time - G Matrix NPD";
PROC MIXED DATA=nilam COVTEST NOCLPRINT NOITPRINT NAMELEN=50 NOINFO METHOD=ML;
	CLASS ID session old;
	MODEL symptoms = daystress|old pmstress|old wpmood|old pmmood|old time|old / SOLUTION DDFM=BW NOTEST;
	RANDOM intercept daystress wpmood time / TYPE=UN SUBJECT=ID GROUP=old GCORR;
	REPEATED session / TYPE=VC SUBJECT=ID GROUP=old;
	ESTIMATE "Intercept: Young" 		intercept 1 old 1 0;
	ESTIMATE "Intercept: Old" 			intercept 1 old 0 1;
	ESTIMATE "Intercept: Age Diff"  	old -1 1;
	ESTIMATE "WP Stress: Young" 		daystress 1 daystress*old 1 0;
	ESTIMATE "WP Stress: Old" 			daystress 1 daystress*old 0 1;
	ESTIMATE "WP Stress: Age Diff"  	daystress*old -1 1;
	ESTIMATE "Context Stress: Young"	pmstress 1 pmstress*old 1 0;
	ESTIMATE "Context Stress: Old" 		pmstress 1 pmstress*old 0 1;
	ESTIMATE "Context Stress: Age Diff" pmstress*old -1 1;
	ESTIMATE "BP Stress: Young" 		daystress 1 pmstress 1 daystress*old 1 0 pmstress*old 1 0;
	ESTIMATE "BP Stress: Old" 			daystress 1 pmstress 1 daystress*old 0 1 pmstress*old 0 1;
	ESTIMATE "BP Stress: Age Diff" 		daystress*old -1 1 pmstress*old -1 1;
	ESTIMATE "WP Mood: Young" 			wpmood 1 wpmood*old 1 0;
	ESTIMATE "WP Mood: Old"				wpmood 1 wpmood*old 0 1;
	ESTIMATE "WP Mood: Age Diff" 		wpmood*old -1 1;
	ESTIMATE "Context Mood: Young" 		wpmood -1 wpmood*old -1 0 pmmood 1 pmmood*old 1 0;
	ESTIMATE "Context Mood: Old"   		wpmood -1 wpmood*old 0 -1 pmmood 1 pmmood*old 0 1;
	ESTIMATE "Context Mood: Age Diff" 	wpmood*old 1 -1 pmmood*old -1 1;
	ESTIMATE "BP Mood: Young" 			pmmood 1 pmmood*old 1 0;
	ESTIMATE "BP Mood: Old" 			pmmood 1 pmmood*old 0 1;
	ESTIMATE "BP Mood: Age Diff" 		pmmood*old -1 1;
	ESTIMATE "Linear Trend: Young" 		time 1 time*old 1 0;
	ESTIMATE "Linear Trend: Old" 		time 1 time*old 0 1;
	ESTIMATE "Linear Trend: Age Diff" 	time*old -1 1;
run;
